﻿using System.Collections.Generic;
using PDollarGestureRecognizer;
using QDollarGestureRecognizer;
using UnityEngine;

namespace PDollarDemo
{
    public enum Recognizer
    {
        P, PPlus, Q, Dollar
    }
    
    public class PRecognizer
    {
        private int _strokeIndex = -1;
        public List<Gesture> trainingSet = new();
        private List<Point> points = new();   // mouse points acquired from the user

        public PRecognizer()
        {
        }

        public void ClearPoints()
        {
            _strokeIndex = -1;
            points.Clear();
        }
        
        public void AddPoints(Vector3[] points)
        {
            _strokeIndex++;
            
            foreach (var point in points)
            {
                AddPoint(point.x, point.z);
            }
        }

        private void AddPoint(float x, float z)
        {
            points.Add(new PDollarGestureRecognizer.Point(x, z, _strokeIndex));
        }

        public string Recognize(Recognizer recognizer)
        {
            return Recognize(recognizer, trainingSet);
        }

        public string Recognize(Recognizer recognizer, List<Gesture> trainingSet)
        {
            Gesture candidate = new Gesture(points.ToArray());

            if (candidate.LUT == null)
                return "";
            
            string gestureClass = "";
            
            switch (recognizer)
            {
                case Recognizer.P: 
                    gestureClass = PointCloudRecognizer.Classify(candidate,trainingSet.ToArray()); 
                    break;
                case Recognizer.PPlus: 
                    gestureClass = PointCloudRecognizerPlus.Classify(candidate,trainingSet.ToArray());  
                    break;
                case Recognizer.Q: 
                    gestureClass = QPointCloudRecognizer.Classify(candidate, trainingSet.ToArray());
                    break;
            }

            return gestureClass;
        }        

        public void SaveGesture(string gestureName)
        {
            if (points.Count == 0) 
                return;

            Gesture gesture = new Gesture(points.ToArray(), gestureName);
            trainingSet.Add(gesture);
        }
    }
}